@@ -1,4 +1,4 @@
-from email_phone_block import block
+from email_phone_block import block, filter_email_phone, filter_email, filter_phone
 import unittest
 
 
@@ -37,6 +37,14 @@ class TestBlock(unittest.TestCase):
     def test_phone_7(self):
         self.assertEqual(block("3333333333"), "xxx-xxx-xxxx")
 
+    def test_email_filter(self):
+        self.assertEqual(filter_email("name@domain.com"), "xxxx@xxxxx.xxx")
+
+    def test_phone_filter(self):
+        self.assertEqual(filter_phone("3333333333"), "xxx-xxx-xxxx")
+
+    def test_email_phone_filter(self):
+        self.assertEqual(filter_email_phone("name@domain.com, 333 333-3333"), "xxxx@xxxxx.xxx, xxx-xxx-xxxx")
 
 if __name__ == '__main__':
     unittest.main()
\ No newline at end of file
